--
-- RiftTool.lua
-- For use with: Rift
-- (c) tgwaste, All rights reserved
--


-- help
--
function showHelp()
 	draw("pink", app .. " Help")
 	draw("grey", "--------------------------")
	draw("grey", "/rt a string", " -- Search the Achievement Database")
	draw("grey", "/rt c string", " -- Search your Currencies [no string for all]")
	draw("grey", "/rt n string", " -- Search the Notoriety Database")
	draw("grey", "/rt g string", " -- Search the Guild roster [no string for all online]")
	draw("grey", "/rt t letter", " -- Toggles Setting (no letter to see list)")
	draw("grey", "/rt w y|n", " -- Toggle WATCH on all NON Carnage quests")
end


-- search currency
--
function searchCurrencies(str)
	for k,v in pairs (Inspect.Currency.List()) do
		local d = Inspect.Currency.Detail(k)
		local stack = comma(d.stack)
		local name = d.name
		local o = name .. " - " .. stack
		if d.stackMax ~= nil then
			o = name .. " - " .. stack .. " / " .. comma(d.stackMax)
		else
		end
		if not str or string.match(name, str) then
			if
				string.match(name, "Platinum") or string.match(name, "Credits") or
				string.match(name, "Planarite") or string.match(name, "Favor") or string.match(name, "Lucky Coin")
			then
				draw("white", o)
			elseif string.match(name, "Empyreal Sourcestone") then
				draw("blue", o)
			elseif string.match(name, "Artisan") or string.match(name, "Summerfest") then
				draw("green", o)
			else
				draw("purple", o)
			end
		end
	end
end


-- search achievement database
--
function searchAchievements(str)
	for k,v in pairs (Inspect.Achievement.List()) do
		local d = Inspect.Achievement.Detail(k)
		if string.match(d.name, str) then
			if d.complete == true then
				draw("green", d.name, " COMPLETE")
			else
				draw("red", d.name, " INCOMPLETE")
			end
		end
	end
end


-- search notoriety database
--
function searchNotorieties(str)
	local repLevel = { 23000, 26000, 36000, 56000, 91000, 151000, 241000 }
	local repColor = { "grey", "white", "yellow", "green", "pink", "pink", "pink" }
	local repName = { "Neutral", "Friendly", "Decorated", "Honored", "Revered", "Glorified", "Venerated" }

	for k,v in pairs (Inspect.Faction.List()) do
		local d = Inspect.Faction.Detail(k)
		if string.match(d.name, str) then
			for i = 1, #repLevel, 1 do
				if d.notoriety <= repLevel[i] then
					if i == 1 then a = i else a = i-1 end
					local max = repLevel[i] - repLevel[a]
					local n = d.notoriety - repLevel[a]
					draw(repColor[a], d.name .. " - " .. n .. "/" .. max .. "  ", repName[a])
					break
				end
			end
		end
	end
end


-- search the guild roster
--
function searchGuild(string)
	local count = 0
	local player = Inspect.Unit.Detail("player")

	for k,x in pairs (Inspect.Guild.Roster.List()) do
		local d = Inspect.Guild.Roster.Detail(k)
		if not string and d.status ~= nil and d.status ~= "mobile" then
			count = count + 1
		end
	end

	if not string then
		draw("pink", "[" .. player.guild .. "] Members online (" .. count .. "): ", string)
	else
		draw("pink", "Results for: ", string)
	end

	for k,x in pairs (Inspect.Guild.Roster.List()) do
		local d = Inspect.Guild.Roster.Detail(k)
		if string and string.match(d.name, string) or not string and d.status ~= nil and d.status ~= "mobile" then
			local rank = Inspect.Guild.Rank.Detail(d.rank)
			local color = "white"
			local flags = "+"
			local zone = " -- OffLine"
			if d.zone ~= nil then
				local z = Inspect.Zone.Detail(d.zone)
				zone = " -- " .. z.name
			end
			if rank.officer ~= nil then color = "yellow" end
			if rank.invite ~= nil then flags = flags .. "i" end
			if rank.kick ~= nil then flags = flags .. "k" end
			if rank.demote ~= nil then flags = flags .. "d" end
			if rank.promote ~= nil then flags = flags .. "p" end
			if rank.officer ~= nil then flags = flags .. "o" end
			if flags == "+" then flags = "" end
			draw(color, d.name .. " (" .. d.level .. ") [" .. rank.name .. "] " .. flags .. zone)
		end
	end
end


-- toggle a settings
--
function toggleSetting(set)
	if not set then
		showToggles()
		return
	end

	if set == "c" or set == "a" then
		if RT.tog_carnagehide == 0 then RT.tog_carnagehide = 1 else RT.tog_carnagehide = 0 end
	end

	if set == "d" or set == "a" then
		if RT.tog_dpsmeter == 0 then RT.tog_dpsmeter = 1 else RT.tog_dpsmeter = 0 end
	end

	if set == "m" or set == "a" then
		if RT.tog_mapcoords == 0 then RT.tog_mapcoords = 1 else RT.tog_mapcoords = 0 end
	end

	if set == "p" or set == "a" then
		if RT.tog_percent == 0 then RT.tog_percent = 1 else RT.tog_percent = 0 end
	end

	if set == "t" or set == "a" then
		if RT.tog_totcurrency == 0 then RT.tog_totcurrency = 1 else RT.tog_totcurrency = 0 end
	end

	if set == "v" or set == "a" then
		if RT.tog_vitality == 0 then RT.tog_vitality = 1 else RT.tog_vitality = 0 end
	end

	showToggles()
end


-- toggle quest watch
--
function toggleWatch(set)
	if not set then
		draw("pink", "Usage: /rt w y|n [y = watch | n = dont watch]")
		return
	end

	if set == "y" then
		draw("green", "Watching the following Quests")
	else
		draw("red", "No longer watching Quests")
	end

	for k,v in pairs (Inspect.Quest.List()) do
		local d = Inspect.Quest.Detail(k)
		if not string.match(d.name, "Carnage") then
			if d.domain == nil then
				print(d.name)
				if set == "y" then
					Command.Quest.Watch(k, true)
				else
					Command.Quest.Watch(k, false)
				end
			end
		end
	end
end


-- commands
--
function Commands(args)
	local cmd = {}
	local numargs = -1

	for token in string.gmatch(args, "[^%s]+") do
		numargs = numargs + 1
		cmd[numargs] = token
	end

	if numargs < 0 then
		draw("pink", "Usage: /rt help")
		return
	end

	if cmd[0] == "help" then
		showHelp()
	end

	if cmd[0] == 'a' then
		searchAchievements(cmd[1])
	end

	if cmd[0] == 'c' then
		searchCurrencies(cmd[1])
	end

	if cmd[0] == "g" then
		searchGuild(cmd[1])
	end

	if cmd[0] == 'n' then
		searchNotorieties(cmd[1])
	end

	if cmd[0] == 't' then
		toggleSetting(cmd[1])
	end

	if cmd[0] == "w" then
		toggleWatch(cmd[1])
	end

	updateAll()
end

