--
-- RiftTool.lua
-- For use with: Rift
-- (c) tgwaste, All rights reserved
--

local addonInfo, private = ...


-- updates the vitality meter
--
function updateVitality()
	if RT.tog_vitality == 0 then
		Vitality:SetText("")
		return
	end

	local player = Inspect.Unit.Detail("player")
	local vitality = player.vitality

	Vitality:SetFontColor(0, 1, 0, 0)
	Vitality:SetText("")

	if vitality ~= nil then
		if vitality < 80 then
			Vitality:SetFontColor(1, 1, 0, 0)
		end
		if vitality < 50 then
			Vitality:SetFontColor(1, 0, 0, 0)
		end
		if vitality < 100 then
			Vitality:SetText(tostring(vitality) .. "%")
		end
	end
end


-- update damage per second
--
function updateDPS(params)
	if RT.tog_dpsmeter == 0 then
		DPS:SetText("")
		return
	end

	updatePerc()

	local player = Inspect.Unit.Detail("player")
	local pet = Inspect.Unit.Detail("player.pet")
	local target = Inspect.Unit.Detail("player.target")

	local nplayer = player.name
	local cplayer = player.combat

	local npet = "nil"
	local cpet = false

	if pet ~= nil then
		npet = pet.name
		cpet = pet.combat
	end

	if cplayer == true or cpet == true then
		if combat == 0 then
			-- start combat
			dps = 0
			damage = 0
			combat = Inspect.Time.Server()
		end
	else
		-- end combat
		if combat == 0 then return end
		mins = 0
		secs = Inspect.Time.Server() - combat
		combat = 0
		DPS:SetText("")
		if dps > 0 then
			if secs > 60 then
				mins = secs / 60
				secs = secs - (mins * 60)
			end
			str = string.format("Damage Per Second: <font color=\"#00ff00\"> %.0f", dps)
			Command.Console.Display("combat", false, str, true)
			str = string.format("Combat Time: <font color=\"#00ff00\"> %d mins and %d seconds", mins, secs)
			Command.Console.Display("combat", false, str, true)
		end
		return
	end

	if not params then return end
	if not params.casterName then return end
	if combat == 0 then return end

	local x = 0
	local now = Inspect.Time.Server()
	local sec = now - combat

	if params.casterName == nplayer or params.casterName == npet then
		if params.damage ~= nil then
			damage = damage + params.damage
			dps = damage / sec
			str = string.format("%.0f", dps)
			if str == "inf" then str = "wait" end
			DPS:SetText(str)
		end
	end
end


-- update the targets life percentage
--
function updatePerc()
	if RT.tog_percent == 0 then
		Perc:SetText("")
		return
	end

	local target = Inspect.Unit.Detail("player.target")

	if target == nil then
		Perc:SetText("")
		return
	end

	if target.relation ~= "hostile" then
		Perc:SetText("")
		return
	end

	local str = string.format("%d%%", target.health / target.healthMax * 100)

	Perc:SetText(str)
end


-- update coordinates
--
function updateCoords()
	if RT.tog_mapcoords == 0 then
		Coords:SetText("")
		return
	end

	player = Inspect.Unit.Detail("player")

	local x = 0
	local z = 0

	if player.coordX ~= nil then
		x = string.format("%d", player.coordX)
	end

	if player.coordZ ~= nil then
		z = string.format("%d", player.coordZ)
	end

	Coords:SetText(x .. " , " .. z)
end


-- auto hide carnage quests
--
function updateCarnage()
	if RT.tog_carnagehide == 0 then
		return
	end

	quests = Inspect.Quest.List()

	for k,v in pairs (quests) do
		detail = Inspect.Quest.Detail(k)
		if string.match(detail.name, "Carnage") and detail.watch == true then
			-- auto hide it
			--
			draw("yellow", "Auto-Hide ", detail.name)
			for j,u in pairs (detail.objective) do
				draw("white", detail.objective[j].description)
			end
			Command.Quest.Watch(k, false)
		end
	end
end


-- shows total currency after a currency gain event
--
function updateCurrency(data)
	if RT.tog_totcurrency == 0 then
		return
	end

	local x = 0

	for k,v in pairs (data) do
		x = x + 1
	end

	if x > 10 then
		-- showing whole list so ignore
		return
	end

	for k,v in pairs (data) do
		local d = Inspect.Currency.Detail(k)
		if not string.match(d.name, "Gold") then
			local stack = comma(d.stack)
			if d.stackMax ~= nil then
				local max = comma(d.stackMax)
				draw("pink", "Total " .. d.name .. ": ", stack .. " / " .. max)
			else
				draw("pink", "Total " .. d.name .. ": ", stack)
			end
		end
	end
end


-- update a map change
--
function testFunction(params)
	--print("for testing")
end


-- initialize
--
function init(data)
	if not RT then
		RT = defaultSettings
	end
	if string.match(data, app) then
		updateVitality()
		updateCoords()
		draw("green", "Loaded RiftTool " .. addonInfo.toc.Version .. " [use /rt help]")
	end
end

